@@ -7,15 +7,15 @@ class Channel:
     def __init__(self, chatId, li, writer):
         self.li = li
         self.writer = writer
-        self.chatId = chatId
+        self.id = chatId
 
     async def __sendPacket(self, command, data):
         packet = Packet(0, 0, command, 0, bson.encode(data))
         return (await self.writer.sendPacket(packet)).toJsonBody()
 
-    async def __sendChat(self, msg, extra, t):
+    async def sendChat(self, msg, extra, t):
         data = {
-            "chatId": self.chatId,
+            "chatId": self.id,
             "extra": extra,
             "type": t,
             "msgId": time.time(),
@@ -25,14 +25,14 @@ class Channel:
         return await self.__sendPacket("WRITE", data)
 
     async def send(self, msg):
-        return await self.__sendChat(msg, "{}", 1)
+        return await self.sendChat(msg, "{}", 1)
 
 
     async def kick(self, member_id):
         if self.li:
             data = {
                 "li": self.li,
-                "c": self.chatId,
+                "c": self.id,
                 "mid": member_id,
             }
             await self.__sendPacket("KICKMEM", data)
@@ -41,7 +41,7 @@ class Channel:
     #     return await self.__sendPacket("INFOLINK", {"lis": [self.li]})
 
     async def get_info(self):
-        return await self.__sendPacket("CHATINFO", {"chatId": self.chatId})
+        return await self.__sendPacket("CHATINFO", {"chatId": self.id})
 
     async def get_user(self, userId):
-        return await self.__sendPacket( "MEMBER", {"chatId": self.chatId, "memberIds": [userId]} )
+        return await self.__sendPacket( "MEMBER", {"chatId": self.id, "memberIds": [userId]} )
