@@ -32,8 +32,9 @@ class HTTP:
         data["device_name"] = 'KakaoV2'
         data["device_uuid"] = self.__device_uuid
         data["os_version"] = "10.0"
-        data["forced"] = True
         data["passcode"] = passcode
+        data["permanent"] = True
+        data["once"] = False
         result = await self.url_open_json("https://katalk.kakao.com/win32/account/register_device.json", data=data, headers=headers)
         if result["status"] == 0:
             return result
@@ -52,7 +53,8 @@ class HTTP:
         data["device_name"] = 'KakaoV2'
         data["device_uuid"] = self.__device_uuid
         data["os_version"] = "10.0"
-        data["forced"] = True
+        data["permanent"] = True
+        data["once"] = False
         result = await self.url_open_json("https://katalk.kakao.com/win32/account/request_passcode.json", data=data, headers=headers)
         if result["status"] == 0:
             return result
@@ -92,6 +94,7 @@ class HTTP:
         data["device_name"] = 'KakaoV2'
         data["device_uuid"] = self.__device_uuid
         data["os_version"] = "10.0"
+        # data["permanent"] = True
         data["forced"] = True
         result = await self.url_open_json('https://katalk.kakao.com/win32/account/login.json', data=data, headers=headers)
         if result["status"] == -100:
@@ -156,13 +159,11 @@ class HTTP:
             self.packetDict[packet.PacketID].set_result(packet)
             del self.packetDict[packet.PacketID]
         body = packet.toJsonBody()
-        
 
         if packet.PacketName == "MSG":
             chatId = body["chatLog"]["chatId"]
             if "li" in body: li = body["li"]
             else: li = 0
-
             channel = Channel(chatId, li, self.__writer)
             msg = Message(self, channel, body)
             self.loop.create_task(self.client.on_message(msg))
